==> haskell-test-framework-quickcheck2-0.3.0.6-397.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-H0xH8C2gPJGnaEmTKj6PE
key:                  test-framework-quickcheck2-0.3.0.6-H0xH8C2gPJGnaEmTKj6PE
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  4f242d3b0ff1439a84faca9b79172295
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-H0xH8C2gPJGnaEmTKj6PE
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    test-framework-0.8.2.2-ITHWZraIqyRCzzqSShCGFx

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.6-401-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-BKrfvnLN9P2avPtTOpexE
key:                  test-framework-quickcheck2-0.3.0.6-BKrfvnLN9P2avPtTOpexE
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  17347c4a3aaa116f094602f5c6213185
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-BKrfvnLN9P2avPtTOpexE
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    test-framework-0.8.2.2-8fX8NEZ5OtDCOpAj0ijyRX

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
